@@ -58,6 +58,7 @@ q(parent)
     m_zOutBtn       = 0;
     m_zSelBtn       = 0;
     m_zFitBtn       = 0;
+    m_clearSelBtn   = 0;
     m_prevBtn       = 0;
     m_scanBtn       = 0;
     m_cancelBtn     = 0;
@@ -818,6 +819,9 @@ void KSaneWidgetPrivate::previewScanDone()
     if (m_optResY != 0) m_optResY->restoreSavedData();
     if (m_optPreview != 0) m_optPreview->restoreSavedData();
 
+    m_previewViewer->setQImage(&m_previewImg);
+    m_previewViewer->zoom2Fit();
+
     if ((m_previewThread->status != SANE_STATUS_GOOD) &&
         (m_previewThread->status != SANE_STATUS_EOF))
     {
@@ -831,8 +835,6 @@ void KSaneWidgetPrivate::previewScanDone()
     m_scanOngoing = false;
     m_updProgressTmr.stop();
     
-    m_previewViewer->updateImage();
-    
     emit (q->scanDone(KSaneWidget::NoError, ""));
     
     return;
@@ -916,9 +918,9 @@ void KSaneWidgetPrivate::oneFinalScanDone()
             QString source;
             m_optSource->getValue(source);
 
-            if (source.contains("Automatic Document Feeder")) {
+            if (source.contains("Automatic Document Feeder") || source.contains("ADF")) {
                 // in batch mode only one area can be scanned per page
-                //kDebug() << "source == \"Automatic Document Feeder\"";
+                //kDebug() << "source == " << source;
                 m_updProgressTmr.start();
                 m_scanThread->start();
                 return;
